@@ -11,8 +11,11 @@ import os
 import time
 from wappushhandler import PushHandler
 import locale
+import osso
 import fmms_config as fMMSconf
 import fmms_sender_ui as fMMSSenderUI
+import gobject
+import dbus
 
 class fMMS_GUI(hildon.Program):
 
@@ -86,6 +89,10 @@ class fMMS_GUI(hildon.Program):
 		
 		if self.config.get_firstlaunch() == 1:
 			print "firstlaunch"
+			self.osso_c = osso.Context("fMMS", "0.1.0", False)
+			note = osso.SystemNote(self.osso_c)
+			firstlaunchmessage = "NOTE: Currently you have to connect manually to the MMS APN when sending and receiving.\n Also, only images is supported as attachment."
+			note.system_note_dialog(firstlaunchmessage , 'notice')
 			self.create_config_dialog()
 			self.config.set_firstlaunch(0)
 		
@@ -117,7 +124,7 @@ class fMMS_GUI(hildon.Program):
 		if buttontext == "Configuration":
 			ret = self.create_config_dialog()
 		elif buttontext == "New MMS":
-			ret = fMMSSenderUI.fMMS_GUI().run()
+			ret = fMMSSenderUI.fMMS_GUI(self.window).run()
 		elif buttontext == "About":
 			ret = self.create_about_dialog()
 		
@@ -139,6 +146,8 @@ class fMMS_GUI(hildon.Program):
 		
 		allVBox = gtk.VBox()
 		
+		
+		
 		apnHBox = gtk.HBox()
 		apn_label = gtk.Label("APN:")
 		self.apn = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
@@ -183,6 +192,9 @@ class fMMS_GUI(hildon.Program):
 		imgwidthHBox.pack_start(imgwidth_label, False, True, 0)
 		imgwidthHBox.pack_start(self.imgwidth, True, True, 0)
 		
+		notelabel = gtk.Label("APN refers to the name of the connection in\n \"Internet Connections\" to use.")
+		
+		allVBox.pack_start(notelabel, False, True, 0)
 		allVBox.pack_start(apnHBox, False, False, 0)
 		allVBox.pack_start(mmscHBox, False, False, 0)
 		allVBox.pack_end(numberHBox, False, False, 0)
@@ -264,7 +276,28 @@ class fMMS_GUI(hildon.Program):
 		miter = model.get_iter(path)
 		# the 4th value is the filename (start counting at 0)
 		filename = model.get_value(miter, 3)
-		self.show_new_window(self, filename)
+		
+		### ugly workaround to get it show instantly
+		bus = dbus.SystemBus()
+		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+		interface.SystemNoteInfoprint ("fMMS: Opening message")
+		
+		
+		gobject.timeout_add(100, self.return_false)
+		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+		# this is ugly i know, but i really want it to work!
+		gobject.timeout_add(50, self.return_false)
+		try:
+			self.show_new_window(self, filename)
+		except:
+			pass
+		# this is ugly i know, but i really want it to work!
+		gobject.timeout_add(50, self.return_false)
+		hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+		
+	def return_false(self):
+		return False
 		
 	""" open a new window containing mms specified by fname """		
 	def show_new_window(self, widget, fname):
