@@ -15,9 +15,11 @@ from wappushhandler import MMSSender
 import osso
 import fmms_config as fMMSconf
 import Image
+import mimetypes
+import dbus
 
 class fMMS_GUI(hildon.Program):
-	def __init__(self):
+	def __init__(self, spawner=None):
 		hildon.Program.__init__(self)
 		program = hildon.Program.get_instance()
 		
@@ -29,7 +31,10 @@ class fMMS_GUI(hildon.Program):
 		
 		self.window.connect("delete_event", self.quit)
 		
-		
+		if spawner != None:
+			self.spawner = spawner
+		else:
+			self.spawner = self.window
 		
 		pan = hildon.PannableArea()
 		pan.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
@@ -101,8 +106,15 @@ class fMMS_GUI(hildon.Program):
 		fcd.set_default_response(gtk.RESPONSE_OK)
 		ret = fcd.run()
 		if ret == gtk.RESPONSE_OK:
-			self.bAttachment.set_label(fcd.get_filename())
-			self.update_size(fcd.get_filename())
+			### filesize check
+			### TODO: dont hardcode
+			filesize = os.path.getsize(fcd.get_filename()) / 1024
+			if filesize > 10240:
+				banner = hildon.hildon_banner_show_information(self.window, "", "10MB attachment limit in effect, please try another file")
+				self.bAttachment.set_label("Attachment")
+			else:
+				self.bAttachment.set_label(fcd.get_filename())
+				self.update_size(fcd.get_filename())
 			fcd.destroy()
 		else:
 			fcd.destroy()
@@ -115,7 +127,13 @@ class fMMS_GUI(hildon.Program):
 			if not os.path.isdir(self.config.get_imgdir()):
 				print "creating dir", self.config.get_imgdir()
 				os.makedirs(self.config.get_imgdir())
-				
+			
+			### TODO: remove ugly hack
+			bus = dbus.SystemBus()
+			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+			interface.SystemNoteInfoprint ("fMMS: Resizing image")
+			
 			img = Image.open(filename)
 			print "height", img.size[1]
 			print "width", img.size[0]
@@ -145,6 +163,7 @@ class fMMS_GUI(hildon.Program):
 	
 	""" sends the message (no shit?) """
 	def send_mms(self, widget):
+		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
 		self.osso_c = osso.Context("fMMS", "0.1.0", False)
 		
 		attachment = self.bAttachment.get_label()
@@ -152,9 +171,11 @@ class fMMS_GUI(hildon.Program):
 			attachment = None
 		else:
 			print attachment
+			filetype = mimetypes.guess_type(attachment)[0]
 			print self.config.get_img_resize_width()
 			self.attachmentIsResized = False
-			if self.config.get_img_resize_width() != 0:
+			print filetype.startswith("image")
+			if self.config.get_img_resize_width() != 0 and filetype.startswith("image"):
 				try:
 					attachment = self.resize_img(attachment)
 				except Exception, e:
@@ -171,15 +192,19 @@ class fMMS_GUI(hildon.Program):
 		print sender, attachment, to, message
 
 		""" Construct and send the message, off you go! """
+		# TODO: remove hardcoded subject
 		try:
 			sender = MMSSender(to, "MMS", message, attachment, sender)
 			(status, reason, output) = sender.sendMMS()
 			### TODO: Clean up and make this look decent
-			message = str(status) + "_" + str(reason) + "_" + str(output)
+			message = str(status) + "_" + str(reason)
 			message = message.replace('\0','')
+			reply = str(output).replace('\0','')
 			#print message
-			banner = hildon.hildon_banner_show_information(widget, "", "MMSC REPLIED: " + message)
-                        banner.set_timeout(5000)
+			#note = osso.SystemNote(self.osso_c)
+			#ret = note.system_note_dialog("MMSC REPLIED:" + message + "\nBODY:" + reply, 'notice')
+			banner = hildon.hildon_banner_show_information(self.window, "", "MMSC REPLIED:" + message + "\nBODY: " + reply)
+                        
 		except TypeError, exc:
 			#print type(exc)
 			note = osso.SystemNote(self.osso_c)
@@ -203,7 +228,7 @@ class fMMS_GUI(hildon.Program):
 		if self.attachmentIsResized == True:
 			print "Removing temporary image..."
 			os.remove(attachment)
-	
+		#self.window.destroy()
 		
 	def update_size(self, fname):
 		try:
